#### doc/directive2_report.txt
~~~
        doc/directive2.md fenced blocks
------------------------------------------------
block    line  test      TEXT or directive
type   number  role      quoted and one per line
------------------------------------------------
py3        14  setup     -setup
py3        23  code
           30  output
py3        40  code
           45  output
py3        50  code
           54  output
py3        62  teardown  -teardown
------------------------------------------------
3 test cases.
~~~
This page is created from a text file that contains the contents
of a plain text file in a fenced code block.
It is included in the documentation as an example text file.
